==> aliyun-python-sdk-imm-1.6.4.tar.gz: aliyun-python-sdk-imm-1.6.4/aliyunsdkimm/request/v20170906/PutProjectRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class PutProjectRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'PutProject','imm')

	def get_CU(self):
		return self.get_query_params().get('CU')

	def set_CU(self,CU):
		self.add_query_param('CU',CU)

	def get_ServiceRole(self):
		return self.get_query_params().get('ServiceRole')

	def set_ServiceRole(self,ServiceRole):
		self.add_query_param('ServiceRole',ServiceRole)

	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)

	def get_BillingType(self):
		return self.get_query_params().get('BillingType')

	def set_BillingType(self,BillingType):
		self.add_query_param('BillingType',BillingType)

	def get_Type(self):
		return self.get_query_params().get('Type')

	def set_Type(self,Type):
		self.add_query_param('Type',Type)

==> aliyun-python-sdk-imm-1.18.0.tar.gz: aliyun-python-sdk-imm-1.18.0/aliyunsdkimm/request/v20170906/PutProjectRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class PutProjectRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'PutProject')
		self.set_method('POST')

	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)

	def get_Type(self):
		return self.get_query_params().get('Type')

	def set_Type(self,Type):
		self.add_query_param('Type',Type)

	def get_CU(self):
		return self.get_query_params().get('CU')

	def set_CU(self,CU):
		self.add_query_param('CU',CU)

	def get_ServiceRole(self):
		return self.get_query_params().get('ServiceRole')

	def set_ServiceRole(self,ServiceRole):
		self.add_query_param('ServiceRole',ServiceRole)

	def get_BillingType(self):
		return self.get_query_params().get('BillingType')

	def set_BillingType(self,BillingType):
		self.add_query_param('BillingType',BillingType)
